@@ -23,7 +23,7 @@ class Publisher(object):
         self.context = zmq.Context()
         self.socket = self.context.socket(zmq.PUB)
         self.socket.set_hwm(256000) # 0 is supposdenly no limit
-        logger.debug(f"topic: {self.topic}")
+        logger.info(f"emitting on {self.topic} every {self.frequency}s")
 
     def __enter__(self):
         self.socket.connect(self.addr)
