@@ -48,7 +48,7 @@ def should_update(last_updated, min_update_interval, debug=False):
            log("last_updated is False")
         return True
 
-    now =  datetime.now(timezone.utc).isoformat()
+    now =  datetime.now(timezone.utc)
     age = now - last_updated
     next_ = min_update_interval - age.seconds
 
@@ -70,7 +70,7 @@ def gettext(message):
     text = message['text']
     have = len(text.strip().split('\n'))
     fillers = '\n'*(max(MAX_LINES - have, 0))
-    timestamp = message['timestamp'].replace("T", " ")[:16]
+    timestamp = datetime.now().isoformat().replace("T", " ")[5:16]
     bottom_right = message.get('bottom_right', '')
     # doesnt handle too long messagse fix later
     return text + fillers + timestamp + bottom_right
@@ -140,8 +140,10 @@ def sub(addr, topic, timeout, debug):
         color = j.get('color', 'black')
 
         # TBB: discard flood messages
-        ts = datetime.strptime(j['timestamp'], "%Y-%m-%dT%H:%M:%S.%f")
-        now =  datetime.now(timezone.utc).isoformat()
+
+        ts = datetime.strptime(j['timestamp'][:-6], "%Y-%m-%dT%H:%M:%S.%f").replace(tzinfo=timezone.utc)
+
+        now =  datetime.now(timezone.utc)
         if ts - now > timedelta(seconds=1.0):
             log("discarding old message: '{}'".format(j['timestamp']))
 
@@ -155,7 +157,7 @@ def sub(addr, topic, timeout, debug):
             inky_write(text, rotation, color)
             if have_inky:
                 log("e-ink screen updated")
-            last_updated =  datetime.now(timezone.utc).isoformat()
+            last_updated =  datetime.now(timezone.utc)
 
         else:
             pass
